# np-upload-validation

AWS upload validation

[![PyPI](https://img.shields.io/pypi/v/np-upload-validation.svg?label=PyPI&color=blue)](https://pypi.org/project/np-upload-validation/)
[![Python version](https://img.shields.io/pypi/pyversions/np-upload-validation)](https://pypi.org/project/np-upload-validation/)

[![Coverage](https://img.shields.io/codecov/c/github/AllenInstitute/np-upload-validation?logo=codecov)](https://app.codecov.io/github/AllenInstitute/np-upload-validation)
[![CI/CD](https://img.shields.io/github/actions/workflow/status/AllenInstitute/np-upload-validation/publish.yml?label=CI/CD&logo=github)](https://github.com/AllenInstitute/np-upload-validation/actions/workflows/publish.yml)
[![GitHub issues](https://img.shields.io/github/issues/AllenInstitute/np-upload-validation?logo=github)](https://github.com/AllenInstitute/np-upload-validation/issues)

# Usage
```bash
conda create -n np_upload_validation python>=3.9
conda activate np_upload_validation
pip install np_upload_validation
```

## Python
```python
>>> import np_upload_validation
```

## Debugging version divergences

```bash
pdm bumpver
```

# Development
See instructions in https://github.com/AllenInstitute/np-upload-validation/CONTRIBUTING.md and the original template: https://github.com/AllenInstitute/copier-pdm-npc/blob/main/README.md